********************************
Converting to/from Other Formats
********************************

.. automodule:: networkx.convert
.. currentmodule:: networkx

Functions
---------

.. autosummary::
   :toctree: generated/

   from_whatever
   to_dict_of_lists
   from_dict_of_lists
   to_dict_of_dicts
   from_dict_of_dicts
   to_edgelist
   from_edgelist
   to_numpy_matrix
   from_numpy_matrix
   to_scipy_sparse_matrix
   from_scipy_sparse_matrix
